@@ -1,47 +1,56 @@
 package Statistics::Descriptive::Smoother;
-
+$Statistics::Descriptive::Smoother::VERSION = '3.0800';
 use strict;
 use warnings;
 
-use Carp;
+use Carp qw/ carp /;
 
-our $VERSION = '3.0702';
+## no critic (ProhibitExplicitReturnUndef)
 
-sub instantiate {
-    my ($class, $args) = @_;
+sub instantiate
+{
+    my ( $class, $args ) = @_;
 
     my $method     = delete $args->{method};
     my $coeff      = delete $args->{coeff} || 0;
     my $ra_samples = delete $args->{samples};
     my $ra_data    = delete $args->{data};
 
-    if ($coeff < 0 || $coeff > 1) {
+    if ( $coeff < 0 || $coeff > 1 )
+    {
         carp("Invalid smoothing coefficient C $coeff\n");
         return;
     }
-    if (@$ra_data < 2) {
+    if ( @$ra_data < 2 )
+    {
         carp("Need at least 2 samples to smooth the data\n");
         return;
     }
-    $method = ucfirst(lc($method));
-    my $sub_class = __PACKAGE__."::$method";
+    $method = ucfirst( lc($method) );
+    my $sub_class = __PACKAGE__ . "::$method";
+    ## no critic
     eval "require $sub_class";
+    ## use critic
     die "No such class $sub_class: $@" if $@;
 
-    return $sub_class->_new({
-        data       => $ra_data,
-        samples    => $ra_samples,
-        count      => scalar @$ra_data,
-        coeff      => $coeff,
-    });
+    return $sub_class->_new(
+        {
+            data    => $ra_data,
+            samples => $ra_samples,
+            count   => scalar @$ra_data,
+            coeff   => $coeff,
+        }
+    );
 }
 
 sub get_smoothing_coeff { $_[0]->{coeff} }
 
-sub set_smoothing_coeff {
-    my ($self, $coeff) = @_;
+sub set_smoothing_coeff
+{
+    my ( $self, $coeff ) = @_;
 
-    if ($coeff < 0 || $coeff > 1) {
+    if ( $coeff < 0 || $coeff > 1 )
+    {
         carp("Invalid smoothing coefficient C $coeff\n");
         return;
     }
@@ -64,7 +73,7 @@ Statistics::Descriptive::Smoother - Base module for smoothing statistical data
 
 =head1 VERSION
 
-version 3.0702
+version 3.0800
 
 =head1 SYNOPSIS
 
@@ -88,10 +97,6 @@ for more details).
 This class is just a factory that will instantiate the object to perform the
 chosen smoothing algorithm.
 
-=head1 VERSION
-
-version 3.0702
-
 =head1 METHODS
 
 =over 5
@@ -165,36 +170,10 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 1997 by Jason Kastner, Andrea Spinelli, Colin Kuskie, and others.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-Statistics-Descriptive/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Statistics::Descriptive::Smoother
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -212,14 +191,6 @@ L<https://metacpan.org/release/Statistics-Descriptive>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Statistics-Descriptive>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -228,22 +199,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=Statistics-Descriptive>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Statistics-Descriptive>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Statistics-Descriptive>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -292,4 +247,24 @@ L<https://github.com/shlomif/perl-Statistics-Descriptive>
 
   git clone git://github.com/shlomif/perl-Statistics-Descriptive.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-Statistics-Descriptive/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 1997 by Jason Kastner, Andrea Spinelli, Colin Kuskie, and others.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
